==> enterprisemodules-ovm_config-1.0.5.tar.gz: enterprisemodules-ovm_config-1.0.5/lib/puppet/type/ovm_repository.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

module Puppet
  # Type responsible for managing of ovm repository available for manager
  Type.newtype(:ovm_repository) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage Oracle Repository.
    Here is an example on how to use this:

        ovm_repository { 'default/repo_1':
          ensure               => 'present',
          presented_to_servers => ['ovs.example.com'],
          share_path           => '/',
          file_system_name     => 'nfs on 192.168.56.5:/var/exports/juno1',
        }

    EOD

    restfull_type('Repository')
    exclude_properties(:file_system, :presented_to_servers)

    validate do
      raise "#{path}: file_system_name is a required property" if file_system_name.nil? && self['ensure'] == :present
    end

    def create_path
      "#{::Puppet_X::EnterpriseModules::Ovm::Type::BASE_PATH}/FileSystem/#{file_system_id}/Repository"
    end

    after_create do
      repo_refresh
    end

    after_modify do
      repo_refresh
    end

    def destroy_path
      "#{::Puppet_X::EnterpriseModules::Ovm::Type::BASE_PATH}/FileSystem/#{file_system_id}/Repository/#{provider.id}"
    end

    def repo_refresh
      with_manager_connection do |connection|
        repository_id = repository_id_for(repository_name)['value']
        parameters    = URI.encode_www_form('repositoryId' => repository_id)
        Puppet.debug "Post a refresh for repository #{repository_name}."
        connection.validated(:put, "#{::Puppet_X::EnterpriseModules::Ovm::Type::BASE_PATH}/Repository/#{repository_id}/refresh?#{parameters}", {} )
      end
    end

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :file_system_name
    parameter :repository_name

    property  :description
    property  :share_path
    property  :presented_to_servers

    add_title_attributes(:repository_name)
  end
end

==> enterprisemodules-ovm_config-1.1.0.tar.gz: enterprisemodules-ovm_config-1.1.0/lib/puppet/type/ovm_repository.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

#
# Type responsible for managing of ovm repository available for manager.
#
module Puppet
  Type.newtype(:ovm_repository) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-DOCS
    This resource allows you manage Oracle Repository.
    Here is an example on how to use this:

        ovm_repository { 'default/repo_1':
          ensure               => 'present',
          presented_to_servers => ['ovs.example.com'],
          share_path           => '/',
          file_system_name     => 'nfs on 192.168.56.5:/var/exports/juno1',
        }

    DOCS

    restfull_type('Repository')
    exclude_properties(:file_system, :presented_to_servers)

    validate do
      raise "#{path}: file_system_name is a required property" if file_system_name.nil? && self['ensure'] == :present
    end

    def create_path
      "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/FileSystem/#{file_system_id}/Repository"
    end

    after_create do
      repo_refresh
    end

    after_modify do
      repo_refresh
    end

    def destroy_path
      "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/FileSystem/#{file_system_id}/Repository/#{provider.id}"
    end

    def repo_refresh
      with_manager_connection do |connection|
        repository_id = repository_id_for(repository_name)['value']
        parameters    = URI.encode_www_form('repositoryId' => repository_id)
        Puppet.debug "Post a refresh for repository #{repository_name}."
        connection.validated(:put, "#{::Puppet_X::EnterpriseModules::Ovm::Dict::BASE_PATH}/Repository/#{repository_id}/refresh?#{parameters}", {})
      end
    end

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :file_system_name
    parameter :repository_name

    property  :description
    property  :share_path
    property  :presented_to_servers

    add_title_attributes(:repository_name)
  end
end
